<?xml version="1.0" encoding="UTF-8"?>
<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns="http://purl.org/rss/1.0/" xmlns:taxo="http://purl.org/rss/1.0/modules/taxonomy/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:syn="http://purl.org/rss/1.0/modules/syndication/" xmlns:admin="http://webns.net/mvcb/">
  <channel rdf:about="http://blog.gmane.org/gmane.comp.lib.glibc.alpha">
    <title>gmane.comp.lib.glibc.alpha</title>
    <link>http://blog.gmane.org/gmane.comp.lib.glibc.alpha</link>
    <description/>
    <syn:updatePeriod>hourly</syn:updatePeriod>
    <syn:updateFrequency>1</syn:updateFrequency>
    <syn:updateBase>1901-01-01T00:00+00:00</syn:updateBase>
    <items>
      <rdf:Seq>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22297"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22296"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22295"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22294"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22293"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22292"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22291"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22290"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22289"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22288"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22287"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22286"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22285"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22284"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22283"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22282"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22281"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22280"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22279"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22278"/>
      </rdf:Seq>
    </items>
    <image rdf:resource="http://gmane.org/img/gmane-25t.png"/>
    <textinput rdf:resource=""/>
  </channel>
  <image rdf:about="http://gmane.org/img/gmane-25t.png">
    <title>Gmane</title>
    <url>http://gmane.org/img/gmane-25t.png</url>
    <link>http://gmane.org</link>
  </image>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22297">
    <title>Re: PATCH: Make chunk size a multiple of MALLOC_ALIGNMENT</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22297</link>
    <description>&lt;pre&gt;
I tried to find a self-contained testcase and failed.


&lt;/pre&gt;</description>
    <dc:creator>H.J. Lu</dc:creator>
    <dc:date>2012-05-24T20:56:26</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22296">
    <title>Re: Please test fix for PR 14112</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22296</link>
    <description>&lt;pre&gt;From: "H.J. Lu" &amp;lt;hjl.tools&amp;lt; at &amp;gt;gmail.com&amp;gt;
Date: Thu, 24 May 2012 13:27:09 -0700


Ok, the problem seemed to be with a kernel change I was
experimenting with.  Once I fixed that all the failures
went away.

So sparc seems fine with your changes, thanks.

&lt;/pre&gt;</description>
    <dc:creator>David Miller</dc:creator>
    <dc:date>2012-05-24T20:55:04</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22295">
    <title>Re: Weekday/Workday for EU locales in glibc</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22295</link>
    <description>&lt;pre&gt;Carlos wanted a 2wk warning period.  When combined with a short vacation 
I have planned at the start of June, well, you end up with a June 6 date.

I can certainly post the patch to fix the EU locales prior to 
disappearing and let Carlos or someone else run with it on the 4th or 
just prior to the 4th if they want.
jeff

&lt;/pre&gt;</description>
    <dc:creator>Jeff Law</dc:creator>
    <dc:date>2012-05-24T20:37:15</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22294">
    <title>Re: Please test fix for PR 14112</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22294</link>
    <description>&lt;pre&gt;From: "H.J. Lu" &amp;lt;hjl.tools&amp;lt; at &amp;gt;gmail.com&amp;gt;
Date: Thu, 24 May 2012 13:27:09 -0700


HJ, I went to sleep right after the email you quoted and I just woke
up, please be patient.

&lt;/pre&gt;</description>
    <dc:creator>David Miller</dc:creator>
    <dc:date>2012-05-24T20:29:19</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22293">
    <title>Re: PATCH: Make chunk size a multiple of MALLOC_ALIGNMENT</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22293</link>
    <description>&lt;pre&gt;The change looks OK to me, though I don't really understand the context
adequately.  It would be good if someone else could review it too.

Do you think you can write an isolated regression test case for this?
It would only fail on x32 before the change, but that's still useful.


Thanks,
Roland

&lt;/pre&gt;</description>
    <dc:creator>Roland McGrath</dc:creator>
    <dc:date>2012-05-24T20:28:34</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22292">
    <title>Re: Please test fix for PR 14112</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22292</link>
    <description>&lt;pre&gt;
Hi David,

I synced hjl/abi with master.  Have you found out what went wrong
for sparc64?

Thanks.


&lt;/pre&gt;</description>
    <dc:creator>H.J. Lu</dc:creator>
    <dc:date>2012-05-24T20:27:09</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22291">
    <title>Re: [PATCH roland/gettimeofday] eliminate INTDEF for gettimeofday</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22291</link>
    <description>&lt;pre&gt;Thanks, I've committed the change.

&lt;/pre&gt;</description>
    <dc:creator>Roland McGrath</dc:creator>
    <dc:date>2012-05-24T20:14:25</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22290">
    <title>Re: [Patch] Testcase for vfprintf bug</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22290</link>
    <description>&lt;pre&gt;From: Jeff Law &amp;lt;law&amp;lt; at &amp;gt;redhat.com&amp;gt;
Date: Thu, 24 May 2012 12:20:24 -0600


That looks really odd to say the least ;-)

&lt;/pre&gt;</description>
    <dc:creator>David Miller</dc:creator>
    <dc:date>2012-05-24T20:05:36</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22289">
    <title>Re: [PATCH roland/gettimeofday] eliminate INTDEF for gettimeofday</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22289</link>
    <description>&lt;pre&gt;
I tested the branch on powerpc[32|64] and it builds and passes make
check just fine.

Ryan

&lt;/pre&gt;</description>
    <dc:creator>Ryan S. Arnold</dc:creator>
    <dc:date>2012-05-24T20:05:26</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22288">
    <title>Re: Weekday/Workday for EU locales in glibc</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22288</link>
    <description>&lt;pre&gt;  Hi!

On Wed, May 23, 2012 at 11:57:17AM -0600, Jeff Law wrote:

  Excellent, thanks for doing this!

  However, the trunk freeze is planned on June 4, isn't it? So it should
land in trunk sooner (ideally leave few days buffer to allow for delays,
I'd say).

Petr "Pasky" Baudis

&lt;/pre&gt;</description>
    <dc:creator>Petr Baudis</dc:creator>
    <dc:date>2012-05-24T20:03:51</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22287">
    <title>Re: [ppc] Include hwcap as ifunc argument</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22287</link>
    <description>&lt;pre&gt;From: Richard Henderson &amp;lt;rth&amp;lt; at &amp;gt;twiddle.net&amp;gt;
Date: Thu, 24 May 2012 07:40:03 -0700


You also have to adjust the IFUNC invocations in dl-machine.h, and
potentially elsewhere in the port.


&lt;/pre&gt;</description>
    <dc:creator>David Miller</dc:creator>
    <dc:date>2012-05-24T19:47:21</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22286">
    <title>PATCH: Make chunk size a multiple of MALLOC_ALIGNMENT</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22286</link>
    <description>&lt;pre&gt;Hi,

do_check_free_chunk has

static void do_check_free_chunk(mstate av, mchunkptr p)
{
  INTERNAL_SIZE_T sz = p-&amp;gt;size &amp;amp; ~(PREV_INUSE|NON_MAIN_ARENA);
  mchunkptr next = chunk_at_offset(p, sz);

  do_check_chunk(av, p);

  /* Chunk must claim to be free ... */
  assert(!inuse(p));
  assert (!chunk_is_mmapped(p));

  /* Unless a special marker, must have OK fields */
  if ((unsigned long)(sz) &amp;gt;= MINSIZE)
  {
    assert((sz &amp;amp; MALLOC_ALIGN_MASK) == 0);

If a free chunk &amp;gt;= MINSIZE, it must be a multiple of MALLOC_ALIGNMENT.
However, when sysmalloc frees old top chunk with size &amp;gt;= MINSIZE, it
doesn't make sure that the size is a multiple of MALLOC_ALIGNMENT:

     /* Setup fencepost and free the old top chunk. */
      /* The fencepost takes at least MINSIZE bytes, because it might
         become the top chunk again later.  Note that a footer is set
         up, too, although the chunk is marked in use. */
      old_size -= MINSIZE;
      set_head(chunk_at_offset(old_top, old_size + 2*SIZE_SZ), 0|PREV_INUSE);
      if (old_size &amp;gt;= MINSIZE) {
        set_head(chunk_at_offset(old_top, old_size), (2*SIZE_SZ)|PREV_INUSE);
        set_foot(chunk_at_offset(old_top, old_size), (2*SIZE_SZ));
        set_head(old_top, old_size|PREV_INUSE|NON_MAIN_ARENA);
        _int_free(av, old_top, 1);
      } else {

This bug caused some test failures in one of nss packages on Linux/x32.
This patch fixes it.  OK to install?

Thanks.


H.J.
---
[BZ #13576]
* malloc/malloc.c (sYSMALLOc): Free the old top chunk with a
multiple of MALLOC_ALIGNMENT in size.
(_int_free): Check chunk size is a multiple of MALLOC_ALIGNMENT.

diff --git a/stdio-common/Makefile b/stdio-common/Makefile
index 02684d2..a5b6f74 100644
--- a/stdio-common/Makefile
+++ b/stdio-common/Makefile
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -56,7 +56,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; tests := tstscanf test_rdwr test-popen tstgetln test-fseek \
  tst-fwrite bug16 bug17 tst-swscanf tst-sprintf2 bug18 bug18a \
  bug19 bug19a tst-popen2 scanf13 scanf14 scanf15 bug20 bug21 bug22 \
  scanf16 scanf17 tst-setvbuf1 tst-grouping bug23 bug24 \
- bug-vfprintf-nargs tst-long-dbl-fphex tst-fphex-wide tst-sprintf3
+ bug-vfprintf-nargs tst-long-dbl-fphex tst-fphex-wide tst-sprintf3 \ bug25
 
 test-srcs = tst-unbputc tst-printf
 
diff --git a/stdio-common/bug25.c b/stdio-common/bug25.c
new file mode 100644
index 0000000..30c13397
--- /dev/null
+++ b/stdio-common/bug25.c
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -0,0 +1,70 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt;
+#include &amp;lt;stdio.h&amp;gt;
+#include &amp;lt;string.h&amp;gt;
+#include &amp;lt;unistd.h&amp;gt;
+
+static const char expected[] = "\
+\n\
+a\n\
+abbcd55\
+\n\
+a\n\
+abbcd55\
+\n\
+a\n\
+abbcd55\
+\n\
+a\n\
+abbcd55\
+\n\
+a\n\
+abbcd55\
+\n\
+a\n\
+abbcd55\
+\n\
+a\n\
+abbcd55\
+\n\
+a\n\
+abbcd55\
+\n\
+a\n\
+abbcd55\
+\n\
+a\n\
+abbcd55\
+\n\
+a\n\
+abbcd55\
+\n\
+a\n\
+abbcd55\
+\n\
+a\n\
+abbcd55%%%%%%%%%%%%%%%%%%%%%%%%%%\n";
+
+static int
+do_test (void)
+{
+  char *buf = malloc (strlen (expected) + 1);
+  snprintf (buf, strlen (expected) + 1,
+    "\n%1$s\n" "%1$s" "%2$s" "%2$s" "%3$s" "%4$s" "%5$d" "%5$d"
+    "\n%1$s\n" "%1$s" "%2$s" "%2$s" "%3$s" "%4$s" "%5$d" "%5$d"
+    "\n%1$s\n" "%1$s" "%2$s" "%2$s" "%3$s" "%4$s" "%5$d" "%5$d"
+    "\n%1$s\n" "%1$s" "%2$s" "%2$s" "%3$s" "%4$s" "%5$d" "%5$d"
+    "\n%1$s\n" "%1$s" "%2$s" "%2$s" "%3$s" "%4$s" "%5$d" "%5$d"
+    "\n%1$s\n" "%1$s" "%2$s" "%2$s" "%3$s" "%4$s" "%5$d" "%5$d"
+    "\n%1$s\n" "%1$s" "%2$s" "%2$s" "%3$s" "%4$s" "%5$d" "%5$d"
+    "\n%1$s\n" "%1$s" "%2$s" "%2$s" "%3$s" "%4$s" "%5$d" "%5$d"
+    "\n%1$s\n" "%1$s" "%2$s" "%2$s" "%3$s" "%4$s" "%5$d" "%5$d"
+    "\n%1$s\n" "%1$s" "%2$s" "%2$s" "%3$s" "%4$s" "%5$d" "%5$d"
+    "\n%1$s\n" "%1$s" "%2$s" "%2$s" "%3$s" "%4$s" "%5$d" "%5$d"
+    "\n%1$s\n" "%1$s" "%2$s" "%2$s" "%3$s" "%4$s" "%5$d" "%5$d"
+    "\n%1$s\n" "%1$s" "%2$s" "%2$s" "%3$s" "%4$s" "%5$d" "%5$d"
+    "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%\n",
+    "a", "b", "c", "d", 5);
+  return strcmp (buf, expected) != 0;
+}
+
+#define TEST_FUNCTION do_test ()
+#include "../test-skeleton.c"
&lt;/pre&gt;</description>
    <dc:creator>Jeff Law</dc:creator>
    <dc:date>2012-05-24T18:20:24</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22278">
    <title>Re: PATCH: Add x32 abilist files</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22278</link>
    <description>&lt;pre&gt;That is fine.

&lt;/pre&gt;</description>
    <dc:creator>Roland McGrath</dc:creator>
    <dc:date>2012-05-24T18:17:07</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22277">
    <title>Re: PATCH: Add x32 C++ type data</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22277</link>
    <description>&lt;pre&gt;That is fine.

&lt;/pre&gt;</description>
    <dc:creator>Roland McGrath</dc:creator>
    <dc:date>2012-05-24T18:16:54</dc:date>
  </item>
  <textinput rdf:about="http://search.gmane.org/?group=$group=gmane.comp.lib.glibc.alpha">
    <title>Search Engine</title>
    <description>Search the mailing list at Gmane</description>
    <name>query</name>
    <link>http://search.gmane.org/?group=$group=gmane.comp.lib.glibc.alpha</link>
  </textinput>
</rdf:RDF>


diff --git a/malloc/malloc.c b/malloc/malloc.c
index bb26937..46826ab 100644
--- a/malloc/malloc.c
+++ b/malloc/malloc.c
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -2390,11 +2390,12 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; static void* sysmalloc(INTERNAL_SIZE_T nb, mstate av)
       top(av) = chunk_at_offset(heap, sizeof(*heap));
       set_head(top(av), (heap-&amp;gt;size - sizeof(*heap)) | PREV_INUSE);
 
-      /* Setup fencepost and free the old top chunk. */
+      /* Setup fencepost and free the old top chunk with a multiple of
+ MALLOC_ALIGNMENT in size. */
       /* The fencepost takes at least MINSIZE bytes, because it might
  become the top chunk again later.  Note that a footer is set
  up, too, although the chunk is marked in use. */
-      old_size -= MINSIZE;
+      old_size = (old_size - MINSIZE) &amp;amp; ~MALLOC_ALIGN_MASK;
       set_head(chunk_at_offset(old_top, old_size + 2*SIZE_SZ), 0|PREV_INUSE);
       if (old_size &amp;gt;= MINSIZE) {
 set_head(chunk_at_offset(old_top, old_size), (2*SIZE_SZ)|PREV_INUSE);
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -3803,8 +3804,10 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; _int_free(mstate av, mchunkptr p, int have_lock)
       malloc_printerr (check_action, errstr, chunk2mem(p));
       return;
     }
-  /* We know that each chunk is at least MINSIZE bytes in size.  */
-  if (__builtin_expect (size &amp;lt; MINSIZE, 0))
+  /* We know that each chunk is at least MINSIZE bytes in size of a
+     multiple of MALLOC_ALIGNMENT.  */
+  if (__builtin_expect (size &amp;lt; MINSIZE
+|| (size &amp;amp; MALLOC_ALIGN_MASK) != 0, 0))
     {
       errstr = "free(): invalid size";
       goto errout;
&lt;/pre&gt;</description>
    <dc:creator>H.J. Lu</dc:creator>
    <dc:date>2012-05-24T19:30:00</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22285">
    <title>Re: [PATCH #14090] md5_process_block() produces incorrect result with large block sizes</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22285</link>
    <description>&lt;pre&gt;
I'm asking for both patches - the initial one contains your patch and 
was tested successfully by me,

Andreas
&lt;/pre&gt;</description>
    <dc:creator>Andreas Jaeger</dc:creator>
    <dc:date>2012-05-24T18:58:45</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22284">
    <title>Re: [Patch] Testcase for vfprintf bug</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22284</link>
    <description>&lt;pre&gt;Good :-)


   But real good trick finding a system
More correctly, the system continues to use the fast path even with a 
printf hook installed.  It's missing this hunk:

   /* Use the slow path in case any printf handler is registered.  */
   if (__builtin_expect (__printf_function_table != NULL
                         || __printf_modifier_table != NULL
                         || __printf_va_arg_table != NULL, 0))
     goto do_positional;

Sorry for the confusion.

jeff

&lt;/pre&gt;</description>
    <dc:creator>Jeff Law</dc:creator>
    <dc:date>2012-05-24T18:51:06</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22283">
    <title>Re: [PATCH v3] add kexec_load() syscall</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22283</link>
    <description>&lt;pre&gt;
I agree it's no less sensible than those.  I think those were dubious
additions too, but they are in the ABI already so it's moot now.  

For anything so arcane it has only one or two users anywhere, and not
performance-critical, calling 'syscall' is really perfectly fine.


Thanks,
Roland

&lt;/pre&gt;</description>
    <dc:creator>Roland McGrath</dc:creator>
    <dc:date>2012-05-24T18:47:23</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22282">
    <title>Re: PATCH: PR libc/12495: Malloc fails if MALLOC_ALIGNMENT &gt; 2 * SIZE_SZ</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22282</link>
    <description>&lt;pre&gt;
Merge these into one entry with the current date and both names.  I
think &amp;lt;drow&amp;lt; at &amp;gt;false.org&amp;gt; is the proper address to use for Daniel now,
but he can confirm.

Use "[BZ #12495]" as per convention.

I don't really understand the malloc code in sufficient detail to judge the
change without a lot of code-reading.  I'm pretty well willing to take your
and Daniel's word on it, but if someone else here can review it that
would be best.


Thanks,
Roland

&lt;/pre&gt;</description>
    <dc:creator>Roland McGrath</dc:creator>
    <dc:date>2012-05-24T18:45:16</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22281">
    <title>Re: PATCH: Add x32 time</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22281</link>
    <description>&lt;pre&gt;
Lovely.  I'll put it in as soon as Ryan verifies the roland/gettimeofday
change on powerpc.


Thanks,
Roland

&lt;/pre&gt;</description>
    <dc:creator>Roland McGrath</dc:creator>
    <dc:date>2012-05-24T18:40:02</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22280">
    <title>Re: [Patch] Testcase for vfprintf bug</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22280</link>
    <description>&lt;pre&gt;The new test looks fine and since it's simpler than the one in the bug
attachment that's better anyway.  But real good trick finding a system
that "pre-dates printf hooks" since IIRC the printf.h interface
actually pre-dates the %n$ support by a few years (and it might well
pre-date Linux, in fact).


Thanks,
Roland

&lt;/pre&gt;</description>
    <dc:creator>Roland McGrath</dc:creator>
    <dc:date>2012-05-24T18:36:30</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22279">
    <title>[Patch] Testcase for vfprintf bug</title>
    <link>http://permalink.gmane.org/gmane.comp.lib.glibc.alpha/22279</link>
    <description>&lt;pre&gt;
I've recently had the need to review glibc's vfprintf code.  During the 
process I discovered that no testcase for bug #13446 was ever installed.

The original testcase in #13446 utilizes the printf hooks mechanism; the 
system where I needed the problem fixed &amp;amp; tested pre-dates printf hooks, 
so I mangled the existing stdio-common/bug23.c test to expose the memory 
allocation bug in #13446.

OK to install?

2012-05-24  Jeff Law  &amp;lt;law&amp;lt; at &amp;gt;redhat.com&amp;gt;

* stdio-common/Makefile (tests): Add bug25.
* stdio-common/bug25.c: New test.
